function  GaussCollLogPlot

% ex: GaussCollLog
% Example 66
% plots the solution to the logistic differential equation
% dy/dt = 50*y*(1-y) aquired by RK collocation methods of order 1-4.
% uses subfunctions gaussQuad, rkcollcoeffs, rkimplssm

% source term
lambda=10;
% differential equation function to solve
fun = @(x) lambda*x*(1-x);
% jacobian of function to solve
jac = @(x) lambda*(1-2*x);
% starting value
y0 = 0.01;
% solution of the differential equtation
sol = @(t) y0./(y0+(1-y0)*exp(-lambda.*t));

% time span
tspan = [0 1];
% number of steps
N = 20;

% intermediate evaluation points
tau=[0.25 0.5 0.75 1];
%tau=[1];

% time points
t = 0:1/(N*length(tau)):1;

% make the figure
figure('Name','Collocation single step methods');

% get exact solution
t_=0:0.01:1; y=sol(t_);
% plot exact solution
plot(t_,y,'--','color',[0 0.75 0],'linewidth',2);
% legend entry for exact solution
leg{1} = 'y(t)';

hold on;

% set markers for RK method solutions
marker = {'b+','m*','c^','rp'};
% solution loop (for all four methods)
for p=1:4
  % make legend entry with order of collocation method
  leg{p+1} = sprintf('s=%d',p);
  % get nodes for collocation method of order p
  [c,w] = gaussQuad(p);
  % get the vector b and matrix A of the butcher-scheme for the collocation
  % method of order p (gaussQuad provides the zeros in interval [-1,1], so
  % a shift with 0.5*(c+1) is needed for interval [0,1])
  [A,b] = collCoeffs(0.5*(c+1),tau);
  % aquire solution using rkimplssm
  [y,vals] = rkimplssm(fun,jac,y0,N,c,b,A);
  % plot the solution points using the marker defined above and the color
  % from the colormap entry
  plot(t,vals,marker{p});
end

% set labels, legend, axes, ...
set(gca,'fontsize',14);
xlabel('t');
ylabel('y');
legend(leg,4);
axis([0,1,0,1.1]);
% write to file
print -dpsc2 'rkkolllog.eps';
