function  GaussCollLogRate
% In this code we compute and plot the convergence rates of approximate 
% solutions to the logistic IVP
%                   dy/dt = lambda*y*(1-y) , y(0) = 0.01
% acquired by RK collocation methods of order 1-4.

% Refinement steps, used for 2^[-2:nsteps]
nsteps=6;
% Source term
lambda=10;
% Right hand side of the ODE
fun = @(x) ;
% Jacobian of the right hand side
jac = @(x) ;
% Initial value
y0 = ;
% Exact solution of the differential equtation
sol = @(t) y0./(y0+(1-y0)*exp(-lambda.*t));

% Intermediate evaluation points
tau = [0.5,1];

% Initialising the error
err_t = zeros(4,nsteps-1);
tol=10^-6;
% Make the figure
figure('Name','Collocation single step methods');
hold on;
% Set markers and initialise the legend and the output
marker = {'b+','m*','c^','rp'};
leg = cell(4, 1);
results = cell(4, 1);

for p = 1:4
    % Get nodes for the appropriate collocation method
    [c] = GaussNodes(p-1);
    
    % Get the vector/matrix b and matrix A of the collocation method
    % Beware that b is of size p x length(tau)
    [A, b] = ;
    
    for i = 2:nsteps
        % Number of steps
        N = ;
        % Time grid
        t = ;
        % Compute the solution using rkimplssm      
        [vals] = rkimplssm(fun, jac, y0, N, c, b, A, tol);
        err_t(p, i-1) = norm(vals-sol(t), Inf);
    end
    plot(2.^-[2:nsteps], err_t(p, :), marker{p});
    % Compute the approximate order of convergence
    fit = polyfit(log(2.^-[2:nsteps]), log(err_t(p, :)), 1);
    % Assigning the legend and the output
    leg{p} = sprintf('s=%d',p);
    results{p} = sprintf('For s = %d the estimated order is %f', p, fit(1));
    
end
% Display the results
sprintf('%s\n', results{:})

% Final touches for the plot
set(gca,'fontsize',14);
set(gca,'Xscale','log','Yscale','log');
xlabel('t');
ylabel('y');
legend(leg, 4);

% Write to file
print -dpsc2 'rkkolllograte.eps';

