function [vals] = rkimplssm(fun, Jac, y0, N, c, b, A, tol)
% In implicit Runge-Kutta method  we need to solve a possibly nonlinear 
% system of equations. Here we will use the damped Newton method.
% INPUTS:
% fun: Right hand side function
% Jac: Jacobian of fun
% y0: initial value
% N: number of steps
% c, b, A: Coefficients characterising the RK-Method
% tol: tolerance for the damped Newton

% Precheck input arguments for consistency
s = size(b, 1);
if ~isequal(size(A),[s s]), error('Size mismatch. Double-check A and b'); end
if (length(c) ~= s), error('c of wrong size'); end

% Initialise the variables
h =  ; % Stepsize
y =  ;  % Set to initial value
vals = y;
% Loop over all the points in the mesh 
for k = 1:N
    % Solve the equation fv(x) = 0
    % As the initial guess use [0, ... , 0]
    % Functions NFun and NJac are defined below
    [gv, ~] = DampedNewton(zeros(s, 1), @NFun, @NJac, 0.5, tol);
    % Check the definition of NFun to infer what does gv correspond to
    yo = y(end);
    % intial value for y
    y = y(end);
    % Compute (all entries of) y by doing one step of the given RK method
    % (with s stages, s being the dimension of A).
    % Notice that if b has more than one column then we ought to compute
    % the intermediate values as well.
     for i=1:s
         y = y + ;
     end

    % Notice that if the size of b is not of the form n x 1 (that is, if
    % the we are computing some intermediate values as well) but rather of
    % the form n x r, then the y computed above will not be a scalar but a
    % r x 1 vector. The last entry in y is the value you should use as yo
    % in the next iteration. The other entries are intermediary values 
    vals = [vals, y];    
end
% Definition of function NFunc
    function fv = NFun(gv)
        fv = gv;
        for j=1:s
            fg = feval(fun,);
            fv = fv - ;
        end
    end
% Definition of function NJac (Jacobi Matrix for NFunc)
    function DF = NJac(gv)
        DF = [];
        for j=1:s
            Jacj = feval(Jac,);
            KP = A(:,j);
            DF = [DF,KP*Jacj];
        end
        DF = eye(s) - ;
    end
end
